==> mobile_pos-1.0.0.tar.gz: lib/src/views/card_payment/widget/share_receipt_sheet.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/card_payment/share_receipt_email.dart';
import 'package:mobile_pos/src/views/card_payment/share_receipt_whatsapp.dart';
import 'package:mobile_pos/src/views/card_payment/widget/qrcode_receipt_share.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class ShareReceiptSheet extends StatelessWidget {
  final String rrn;
  const ShareReceiptSheet({super.key, required this.rrn});

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(20),
          const RavenPayBottomSheetCapsule(),
          const Gap(16),
          Row(
            children: [
              Expanded(
                  child: Text("Share Receipt",
                      style: headling1.copyWith(fontSize: 20))),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: RoundedItemContainer(
                    asset: "cancel_icon.png",
                    imageColor: pluginTheme.isLightTheme ? null : Colors.white),
              ),
            ],
          ),
          const Gap(24),
          items(
              asset: "whatsapp_icon.png",
              name: "Via WhatsApp",
              fgColor: AppColors.ravenSuccessColor.withOpacity(0.1),
              onTap: () {
                Navigator.pop(context);
                pushRoute(
                    context,
                    ShareReceiptWhatsapp(
                      rrn: rrn,
                    ));
              }),
          items(
              asset: "email_icon.png",
              name: "Via Email",
              fgColor: AppColors.lightBlue.withOpacity(0.1),
              onTap: () {
                Navigator.pop(context);
                pushRoute(
                    context,
                    ShareReceiptEmail(
                      rrn: rrn,
                    ));
              }),
          items(
              asset: "qr_code_icon.png",
              name: "Via QR Code ",
              fgColor: AppColors.lightPurple.withOpacity(0.1),
              onTap: () async {
                var response = await ApiRequests.getQrCodeLink(context, rrn);
                Navigator.pop(context);
                if (response.runtimeType == bool) {
                  return;
                }
                showRavenPayBottomSheet(context,
                    child: QrCodeReceiptShare(
                      data: response,
                    ));
              },
              showBorder: false),
        ],
      ),
    );
  }

  Widget items(
      {required String name,
      required String asset,
      required Color fgColor,
      required Function onTap,
      bool showBorder = true}) {
    return InkWell(
      splashColor: Colors.transparent,
      highlightColor: Colors.transparent,
      onTap: () => onTap(),
      child: Column(
        children: [
          Row(
            children: [
              Container(
                  padding: const EdgeInsets.all(8),
                  height: 38,
                  width: 38,
                  decoration:
                      BoxDecoration(shape: BoxShape.circle, color: fgColor),
                  child: Image.asset(
                    loadAsset(asset),
                  )),
              const Gap(12),
              Expanded(
                child: Text(name, style: headling2.copyWith(fontSize: 16)),
              ),
              Icon(
                Icons.arrow_forward_ios_outlined,
                color: subtitle.color,
                size: 14,
              )
            ],
          ),
          if (showBorder) ...[
            Divider(
                height: 28,
                color: AppColors.ravenLightGrey
                    .withOpacity(pluginTheme.isLightTheme ? 0.7 : 0.08))
          ] else ...[
            const Gap(28)
          ]
        ],
      ),
    );
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/src/views/card_payment/widget/share_receipt_sheet.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/card_payment/share_receipt_email.dart';
import 'package:mobile_pos/src/views/card_payment/share_receipt_whatsapp.dart';
import 'package:mobile_pos/src/views/card_payment/widget/qrcode_receipt_share.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class ShareReceiptSheet extends StatelessWidget {
  final String rrn;
  final String? category;
  const ShareReceiptSheet({super.key, required this.rrn, this.category});

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(20),
          const RavenPayBottomSheetCapsule(),
          const Gap(16),
          Row(
            children: [
              Expanded(
                  child: Text("Share Receipt",
                      style: headling1.copyWith(fontSize: 20))),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: RoundedItemContainer(
                    asset: "cancel_icon.png",
                    imageColor: pluginTheme.isLightTheme ? null : Colors.white),
              ),
            ],
          ),
          const Gap(24),
          items(
              asset: "whatsapp_icon.png",
              name: "Via WhatsApp",
              fgColor: AppColors.ravenSuccessColor.withOpacity(0.1),
              onTap: () {
                Navigator.pop(context);
                pushRoute(
                    context,
                    ShareReceiptWhatsapp(
                      rrn: rrn,
                      category: category,
                    ));
              }),
          items(
              asset: "email_icon.png",
              name: "Via Email",
              fgColor: AppColors.lightBlue.withOpacity(0.1),
              onTap: () {
                Navigator.pop(context);
                pushRoute(
                    context,
                    ShareReceiptEmail(
                      rrn: rrn,
                      category: category,
                    ));
              }),
          items(
              asset: "qr_code_icon.png",
              name: "Via QR Code ",
              fgColor: AppColors.lightPurple.withOpacity(0.1),
              onTap: () async {
                var response = await ApiRequests.getQrCodeLink(context, rrn,
                    category: category);
                Navigator.pop(context);
                if (response.runtimeType == bool) {
                  return;
                }
                showRavenPayBottomSheet(context,
                    child: QrCodeReceiptShare(
                      data: response,
                    ));
              },
              showBorder: false),
        ],
      ),
    );
  }

  Widget items(
      {required String name,
      required String asset,
      required Color fgColor,
      required Function onTap,
      bool showBorder = true}) {
    return InkWell(
      splashColor: Colors.transparent,
      highlightColor: Colors.transparent,
      onTap: () => onTap(),
      child: Column(
        children: [
          Row(
            children: [
              Container(
                  padding: const EdgeInsets.all(8),
                  height: 38,
                  width: 38,
                  decoration:
                      BoxDecoration(shape: BoxShape.circle, color: fgColor),
                  child: Image.asset(
                    loadAsset(asset),
                  )),
              const Gap(12),
              Expanded(
                child: Text(name, style: headling2.copyWith(fontSize: 16)),
              ),
              Icon(
                Icons.arrow_forward_ios_outlined,
                color: subtitle.color,
                size: 14,
              )
            ],
          ),
          if (showBorder) ...[
            Divider(
                height: 28,
                color: AppColors.ravenLightGrey
                    .withOpacity(pluginTheme.isLightTheme ? 0.7 : 0.08))
          ] else ...[
            const Gap(28)
          ]
        ],
      ),
    );
  }
}
